@@ -44,10 +44,10 @@ class ChargingSession(Base):
     ended = Column(DatetimeDecorator)
     unlocked = Column(DatetimeDecorator)
     disconnected = Column(DatetimeDecorator)
-    maxChargeCurrentACSetting = Column(Enum(MaximumChargeCurrent, length=63))
+    maxChargeCurrentACSetting = Column(Enum(MaximumChargeCurrent))
     targetSOCSetting_pct = Column(Integer)
     maximumChargePower_kW = Column(Float)
-    acdc = Column(Enum(ACDC, length=63))
+    acdc = Column(Enum(ACDC))
     startSOC_pct = Column(Integer)
     endSOC_pct = Column(Integer)
     mileage_km = Column(Integer)
